pub type VClock8<K> = VClock<K, u8>;Expand description
Vector clock using u8 counters.
About capacity: after 256 updates, this will overflow and yield false results. Use only if you really want to save memory space (not sure you would save anything on modern hardware) of for prototyping.
When it overflows, it will panic() in debug mode, and silently ignore in release mode.
Examples
use vclock::VClock8;
// key type can be inferred
let mut c = VClock8::default();
c.incr(&"a");
c.incr(&"a");
c.incr(&"b");
assert_eq!(Some(1), c.get(&"a"));
assert_eq!(Some(0), c.get(&"b"));
assert_eq!(None, c.get(&"c"));Aliased Type
pub struct VClock8<K> { /* private fields */ }